@@ -9,7 +9,7 @@ use File::Spec;
 use Git::Code::Review::Utilities qw(:all);
 use Git::Code::Review -command;
 use POSIX qw(strftime);
-use Text::Wrap qw(wrap);
+use Text::Wrap qw(fill);
 use YAML;
 
 sub opt_spec {
@@ -36,7 +36,7 @@ sub execute {
     my $sha1   = $args->[0];
     my $audit  = gcr_repo();
     my $source = gcr_repo('source');
-    gcr_reset();
+    gcr_reset($_) for qw(audit source);
 
     # Commit Information
     my @data = $source->run(qw(log -n 1 --stat -r),$sha1);
@@ -48,8 +48,10 @@ sub execute {
     output({clear=>1},@data);
     debug_var({gcr_commit_info($sha1)});
 
-    my @log_options = (qw(--reverse -F -S), $sha1);
+    my @log_options = qw(--reverse --);
+    push @log_options, sprintf "*/%s**", $sha1;
     my $logs = $audit->log(@log_options);
+    debug({color=>'cyan'}, "Running: git log ". join(' ', map { /\s/ ? "'$_'" : $_ } @log_options));
 
     output({color=>'green',clear=>1},
         '#'x80,
@@ -79,10 +81,10 @@ sub execute {
             push @output, $data->{$key} if exists $data->{$key};
         }
 
-        debug_var($data);
         output({indent=>1,color=>$color,data=>1}, join("\t", @output));
         if(exists $data->{message} && $state ne 'locked') {
-            verbose({indent=>2}, $_) for split /\r?\n/, wrap("", "", $data->{message});
+            my $message = exists $data->{fixed_by} ? join('  ', $data->{message}, "Fixed by: $data->{fixed_by}") : $data->{message};
+            verbose({indent=>2}, $_) for split /\r?\n/, fill("", "", $message);
         }
     }
 }
@@ -101,7 +103,7 @@ Git::Code::Review::Command::show - Quick overview of the History for the Commmit
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 AUTHOR
 
