@@ -23,8 +23,6 @@ my $PROFILE = gcr_profile();
 my @TEMPLATE_DIR = ( gcr_mkdir('.code-review','templates') );
 my $PROFILE_DIR = File::Spec->catdir(gcr_dir(), qw(.code-review profiles),$PROFILE,'templates');
 unshift @TEMPLATE_DIR, $PROFILE_DIR if -d $PROFILE_DIR;
-debug("Template search path:");
-debug_var(\@TEMPLATE_DIR);
 $Template::Stash::HASH_OPS->{nsort_by_value} = sub {
     my ($hash) = @_;
     return sort { $hash->{$a} <=> $hash->{$b} } keys %{ $hash };
@@ -40,6 +38,8 @@ sub notify {
 
     debug({color=>'magenta'}, "called Git::Code::Review::Notify::notify");
     debug_var($opts);
+    debug("Template search path");
+    debug_var(\@TEMPLATE_DIR);
 
     # Plugin Settings
     my %Plugins = (
@@ -79,6 +79,7 @@ sub notify {
     my @META = (
         'GCR_REPO_AUDIT=' . gcr_origin('audit'),
         'GCR_REPO_SOURCE=' . gcr_origin('source'),
+        'GCR_NOTIFICATION=' . $name,
     );
 
     # Add commit data
@@ -283,6 +284,23 @@ my %_DEFAULTS = (
             [% month %]: [% profiles.$profile.$month %]
         [% END %]
         [% END -%]
+
+        [% IF concerns.keys.size > 0 -%]
+        [% FOREACH profile IN concerns.keys.sort -%]
+        [% concerns.$profile.keys.size %] Active [% profile.ucfirst %] Concerns
+        ----
+        [% FOREACH sha1 IN concerns.$profile.keys.sort -%]
+        [% sha1 %]
+          * [% concerns.$profile.$sha1.commit.date %] authored by [% concerns.$profile.$sha1.commit.by %]
+          * [% concerns.$profile.$sha1.concern.date %] raised for *[% concerns.$profile.$sha1.concern.reason %]* by [% concerns.$profile.$sha1.concern.by %]
+
+        [% FILTER indent('  ') -%]
+        [% concerns.$profile.$sha1.concern.explanation %]
+        [% END -%]
+
+        [% END -%]
+        [% END -%]
+        [% END -%]
     },
 );
 
@@ -330,7 +348,7 @@ Git::Code::Review::Notify - Notification framework
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 AUTHOR
 
